<div align="center">
<img src="assets/youtube_analyzer-logo.png" alt="youtube_analyzer-logo" width="200"/>

![Versão](https://img.shields.io/badge/version-1.0-orange)
![Licença](https://img.shields.io/badge/license-MIT-orange)
[![Sponsor](https://img.shields.io/badge/📖Documentation-green)](https://github.com/PauloCesar-dev404/youtube_analyzer/blob/main/Docs/document.md)
<br><br>
<i>Obtenha detalhes completos de vídeos do YouTube com esta biblioteca incrível!</i>
<br>
</div>

### Funcionalidades
- [x] Obter detalhes de um vídeo
- [x] Obter legendas
- [x] Tradução de legendas
- [x] Analisar playlists
- [x] Obter detalhes de URIs de vídeos
- [x] Downloads de áudios e vídeos


---

### Contribuições
Se tiver dúvidas ou sugestões, abra uma [issue aqui](https://github.com/PauloCesar-dev404/youtube_analyzer/issues).

---

### Apoie o Projeto com Pix!
**Clique no código abaixo para copiá-lo automaticamente e ajudar a manter o desenvolvimento.**  
```
00020126580014br.gov.bcb.pix0136cb39b3a7-1a18-4d8d-9a33-996354ab93f55204000053039865802BR5925Paulo Cesar Ferro Fernand6009Sao Paulo62070503***6304E75F
```

---

<i>youtube_analyzer! 🚀</i>


